@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2010 The Music Player Daemon Project
+ * (c) 2004-2017 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,6 +24,8 @@
 #include "ncmpc_curses.h"
 #include "Compiler.h"
 
+#include <stdbool.h>
+
 enum color {
 	COLOR_TITLE = 1,
 	COLOR_TITLE_BOLD,
@@ -47,11 +49,17 @@ gcc_pure
 int colors_str2color(const char *str);
 
 #ifdef ENABLE_COLORS
-int colors_assign(const char *name, const char *value);
-int colors_define(const char *name, short r, short g, short b);
-int colors_start(void);
+bool
+colors_assign(const char *name, const char *value);
+
+bool
+colors_define(const char *name, short r, short g, short b);
+
+void
+colors_start(void);
 #endif
 
-int colors_use(WINDOW *w, enum color id);
+void
+colors_use(WINDOW *w, enum color id);
 
 #endif /* COLORS_H */
