@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2010 The Music Player Daemon Project
+ * (c) 2004-2017 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,13 +20,24 @@
 #ifndef LIRC_H
 #define LIRC_H
 
-#include "command.h"
-#include <glib.h>
+#include "config.h"
 
-int ncmpc_lirc_open(void);
-void ncmpc_lirc_close(void);
+#ifdef ENABLE_LIRC
 
-gboolean
-lirc_event(GIOChannel *source, GIOCondition condition, gpointer data);
+void
+ncmpc_lirc_init(void);
+
+void
+ncmpc_lirc_deinit(void);
+
+#else
+
+static inline void
+ncmpc_lirc_init(void) {}
+
+static inline void
+ncmpc_lirc_deinit(void) {}
+
+#endif
 
 #endif
