@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2010 The Music Player Daemon Project
+ * (c) 2004-2017 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -48,8 +48,16 @@ struct list_window {
 
 	unsigned start;
 	unsigned selected;
-	unsigned range_base;        /* represents the base item. */
-	bool range_selection;       /* range selection activated */
+
+	/**
+	 * Represents the base item.
+	 */
+	unsigned range_base;
+
+	/**
+	 * Range selection activated?
+	 */
+	bool range_selection;
 
 	bool hide_cursor;
 };
