@@ -1,6 +1,7 @@
 #ifndef MPDCLIENT_H
 #define MPDCLIENT_H
 
+#include "config.h"
 #include "playlist.h"
 #include "Compiler.h"
 
@@ -9,26 +10,71 @@
 struct filelist;
 
 struct mpdclient {
+#ifdef ENABLE_ASYNC_CONNECT
+	/**
+	 * These settings are used to connect to MPD asynchronously.
+	 */
+	struct mpd_settings *settings;
+
+#ifndef WIN32
+	/**
+	 * A second set of settings, just in case #settings did not
+	 * work.  This is only used if #settings refers to a local
+	 * socket path, and this one is supposed to be a fallback to
+	 * IP on the default port (6600).
+	 */
+	struct mpd_settings *settings2;
+#endif
+
+#else
+	const char *host;
+	unsigned port;
+#endif
+
+	unsigned timeout_ms;
+
+	const char *password;
+
 	/* playlist */
 	struct mpdclient_playlist playlist;
 
+#ifdef ENABLE_ASYNC_CONNECT
+	struct aconnect *async_connect;
+#endif
+
 	struct mpd_connection *connection;
 
+	/**
+	 * Tracks idle events.  It is automatically called by
+	 * mpdclient_get_connection().
+	 */
+	struct mpd_glib_source *source;
+
+	struct mpd_status *status;
+	const struct mpd_song *song;
+
+	/**
+	 * The GLib source id which re-enters MPD idle mode before the
+	 * next main loop interation.
+	 */
+	unsigned enter_idle_source_id;
+
 	/**
 	 * This attribute is incremented whenever the connection changes
 	 * (i.e. on disconnection and (re-)connection).
 	 */
 	unsigned connection_id;
 
+	int volume;
+
 	/**
-	 * If this object is non-NULL, it tracks idle events.  It is
-	 * automatically called by mpdclient_get_connection() and
-	 * mpdclient_put_connection().  It is not created by the
-	 * mpdclient library; the user of this library has to
-	 * initialize it.  However, it is freed when the MPD
-	 * connection is closed.
+	 * A bit mask of idle events occurred since the last update.
 	 */
-	struct mpd_glib_source *source;
+	enum mpd_idle events;
+
+#if defined(ENABLE_ASYNC_CONNECT) && !defined(WIN32)
+	bool connecting2;
+#endif
 
 	/**
 	 * This attribute is true when the connection is currently in
@@ -36,16 +82,10 @@ struct mpdclient {
 	 */
 	bool idle;
 
-	struct mpd_status *status;
-	const struct mpd_song *song;
-
-	int volume;
-	unsigned update_id;
-
 	/**
-	 * A bit mask of idle events occurred since the last update.
+	 * Is MPD currently playing?
 	 */
-	enum mpd_idle events;
+	bool playing;
 };
 
 enum {
@@ -61,11 +101,9 @@ enum {
 		| MPD_IDLE_OUTPUT
 		| MPD_IDLE_OPTIONS
 		| MPD_IDLE_UPDATE
-#if LIBMPDCLIENT_CHECK_VERSION(2,5,0)
 		| MPD_IDLE_STICKER
 		| MPD_IDLE_SUBSCRIPTION
 		| MPD_IDLE_MESSAGE
-#endif
 };
 
 /** functions ***************************************************************/
@@ -81,10 +119,21 @@ mpdclient_finish_command(struct mpdclient *c)
 }
 
 struct mpdclient *
-mpdclient_new(void);
+mpdclient_new(const gchar *host, unsigned port,
+	      unsigned timeout_ms, const gchar *password);
 
 void mpdclient_free(struct mpdclient *c);
 
+/**
+ * Determine a human-readable "name" of the settings currently used to
+ * connect to MPD.
+ *
+ * @return an allocated string that needs to be freed (with g_free())
+ * by the caller
+ */
+char *
+mpdclient_settings_name(const struct mpdclient *c);
+
 gcc_pure
 static inline bool
 mpdclient_is_connected(const struct mpdclient *c)
@@ -92,6 +141,21 @@ mpdclient_is_connected(const struct mpdclient *c)
 	return c->connection != NULL;
 }
 
+/**
+ * Is this object "dead"?  i.e. not connected and not currently doing
+ * anything to connect.
+ */
+gcc_pure
+static inline bool
+mpdclient_is_dead(const struct mpdclient *c)
+{
+	return c->connection == NULL
+#ifdef ENABLE_ASYNC_CONNECT
+		&& c->async_connect == NULL
+#endif
+		;
+}
+
 gcc_pure
 static inline bool
 mpdclient_is_playing(const struct mpdclient *c)
@@ -110,9 +174,8 @@ mpdclient_get_current_song(const struct mpdclient *c)
 		: NULL;
 }
 
-bool
-mpdclient_connect(struct mpdclient *c, const gchar *host, gint port,
-		  unsigned timeout_ms, const gchar *password);
+void
+mpdclient_connect(struct mpdclient *c);
 
 void
 mpdclient_disconnect(struct mpdclient *c);
@@ -123,16 +186,6 @@ mpdclient_update(struct mpdclient *c);
 struct mpd_connection *
 mpdclient_get_connection(struct mpdclient *c);
 
-void
-mpdclient_put_connection(struct mpdclient *c);
-
-/**
- * To be implemented by the application: mpdclient.c calls this to
- * display an error message.
- */
-void
-mpdclient_ui_error(const char *message);
-
 /*** MPD Commands  **********************************************************/
 
 bool
@@ -165,7 +218,6 @@ mpdclient_cmd_delete_range(struct mpdclient *c, unsigned start, unsigned end);
 bool
 mpdclient_cmd_move(struct mpdclient *c, unsigned dest, unsigned src);
 
-#if LIBMPDCLIENT_CHECK_VERSION(2,5,0)
 bool
 mpdclient_cmd_subscribe(struct mpdclient *c, const char *channel);
 
@@ -181,7 +233,6 @@ mpdclient_send_read_messages(struct mpdclient *c);
 
 struct mpd_message *
 mpdclient_recv_message(struct mpdclient *c);
-#endif
 
 /*** playlist functions  **************************************************/
 
@@ -197,10 +248,4 @@ mpdclient_playlist_update_changes(struct mpdclient *c);
 bool
 mpdclient_filelist_add_all(struct mpdclient *c, struct filelist *fl);
 
-/* sort by song format */
-gcc_pure
-gint compare_filelistentry_format(gconstpointer filelist_entry1,
-				  gconstpointer filelist_entry2,
-				  const char *song_format);
-
 #endif
