@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2010 The Music Player Daemon Project
+ * (c) 2004-2017 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -269,13 +269,13 @@ screen_lyrics_reload(void)
 }
 
 static void
-lyrics_screen_init(WINDOW *w, int cols, int rows)
+lyrics_screen_init(WINDOW *w, unsigned cols, unsigned rows)
 {
 	screen_text_init(&text, w, cols, rows);
 }
 
 static void
-lyrics_resize(int cols, int rows)
+lyrics_resize(unsigned cols, unsigned rows)
 {
 	screen_text_resize(&text, cols, rows);
 }
@@ -363,11 +363,9 @@ lyrics_edit(void)
 	}
 
 	if (options.text_editor_ask) {
-		char *buf = g_strdup_printf(
-		    _("Do you really want to start an editor and edit these lyrics [%s/%s]? "),
-					    YES, NO);
-		bool really = screen_get_yesno(buf, false);
-		g_free(buf);
+		const char *prompt =
+			_("Do you really want to start an editor and edit these lyrics?");
+		bool really = screen_get_yesno(prompt, false);
 		if (!really) {
 			screen_status_message(_("Aborted"));
 			return;
@@ -453,7 +451,7 @@ lyrics_cmd(struct mpdclient *c, command_t cmd)
 	case CMD_LYRICS_UPDATE:
 		if (c->song != NULL) {
 			screen_lyrics_load(c->song);
-			screen_text_repaint(&text);
+			screen_text_paint(&text);
 		}
 		return true;
 	case CMD_EDIT:
