@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2010 The Music Player Daemon Project
+ * (c) 2004-2017 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,11 +20,6 @@
 #ifndef NCMPC_SCREEN_QUEUE_H
 #define NCMPC_SCREEN_QUEUE_H
 
-struct mpdclient;
-
 extern const struct screen_functions screen_queue;
 
-int
-playlist_save(struct mpdclient *c, char *name, char *defaultname);
-
 #endif
