@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2010 The Music Player Daemon Project
+ * (c) 2004-2017 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -49,8 +49,4 @@ char *screen_readln(const char *prompt, const char *value,
 
 void screen_display_completion_list(GList *list);
 
-#ifndef NCMPC_MINI
-void set_xterm_title(const char *format, ...);
-#endif
-
 #endif
