@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2010 The Music Player Daemon Project
+ * (c) 2004-2017 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@
 
 #include "strfsong.h"
 #include "charset.h"
-#include "utils.h"
+#include "time_format.h"
 
 #include <mpd/client.h>
 
@@ -232,6 +232,8 @@ _strfsong(gchar *s,
 		}
 		else if (strncmp("%track%", p, n) == 0)
 			temp = song_tag_locale(song, MPD_TAG_TRACK);
+		else if (strncmp("%disc%", p, n) == 0)
+			temp = song_tag_locale(song, MPD_TAG_DISC);
 		else if (strncmp("%name%", p, n) == 0)
 			temp = song_tag_locale(song, MPD_TAG_NAME);
 		else if (strncmp("%date%", p, n) == 0)
